/**********************************************************************************
* File: Lab_5_6_7.cmd -- File for Lab 5, 6 and 7 (Boot to SARAM boot mode)
* Devices: TMS320F28379D
* Author: C2000 Technical Training, Texas Instruments
**********************************************************************************/

MEMORY
{
PAGE 0:    /* Program Memory */
   BEGIN_M0            : origin = 0x000000, length = 0x000002     /* Part of M0 RAM - used for "Boot to M0" bootloader mode */
   RAMLS4              : origin = 0x00A000, length = 0x000800     /* L4 RAM, DCSM secure, CLA Program RAM */
   RAMLS5              : origin = 0x00A800, length = 0x000800     /* L5 RAM, DCSM secure, CLA Program RAM */
   RAMGS0123           : origin = 0x00C000, length = 0x004000     /* GS0-3 RAM, Parity, DMA */

   /* Flash sectors */
   BEGIN_FLASH         : origin = 0x080000, length = 0x000002     /* Part of FLASH Sector A - used for "Jump to flash" bootloader mode */
   FLASH_A             : origin = 0x080002, length = 0x001FFE     /* Part of FLASH Sector A - DCSM secure */
   FLASH_BCDEFG        : origin = 0x082000, length = 0x01E000     /* FLASH Sectors B,C,D,E,F,G combined - DCSM secure */
   /* FLASHB           : origin = 0x082000, length = 0x002000	/* on-chip Flash Sector B - DCSM secure */
   /* FLASHC           : origin = 0x084000, length = 0x002000	/* on-chip Flash Sector C - DCSM secure */
   /* FLASHD           : origin = 0x086000, length = 0x002000	/* on-chip Flash Sector D - DCSM secure */
   /* FLASHE           : origin = 0x088000, length = 0x008000	/* on-chip Flash Sector E - DCSM secure */
   /* FLASHF           : origin = 0x090000, length = 0x008000	/* on-chip Flash Sector F - DCSM secure */
   /* FLASHG           : origin = 0x098000, length = 0x008000	/* on-chip Flash Sector G - DCSM secure */
   /* FLASHH           : origin = 0x0A0000, length = 0x008000	/* on-chip Flash Sector H - DCSM secure */
   /* FLASHI           : origin = 0x0A8000, length = 0x008000	/* on-chip Flash Sector I - DCSM secure */
   FLASHJ           : origin = 0x0B0000, length = 0x008000	/* on-chip Flash Sector J - DCSM secure */
   FLASHK           : origin = 0x0B8000, length = 0x002000	/* on-chip Flash Sector K - DCSM secure */
   FLASHL           : origin = 0x0BA000, length = 0x002000	/* on-chip Flash Sector L - DCSM secure */
   FLASHMN          : origin = 0x0BC000, length = 0x003FF0	/* on-chip Flash Sector M - DCSM secure */
   /*FLASHM           : origin = 0x0BC000, length = 0x002000	/* on-chip Flash Sector M - DCSM secure */
   /*FLASHN           : origin = 0x0BE000, length = 0x001FF0	/* on-chip Flash Sector N - DCSM secure */


   RESET           (R) : origin = 0x3FFFC0, length = 0x000002     /* Part of Boot ROM */

PAGE 1:    /* Data Memory */
   BOOT_RSVD           : origin = 0x000002, length = 0x00004E     /* Part of M0 RAM, BOOT rom will use this for stack */
   RAMM0               : origin = 0x000050, length = 0x0003B0     /* M0 RAM */
   RAMM1               : origin = 0x000400, length = 0x0003F8     /* M1 RAM */
   RAMM1_RSVD          : origin = 0x0007F8, length = 0x000008
   CLA1_MSGRAMLOW      : origin = 0x001480, length = 0x000080     /* CLA to CPU Message RAM, DCSM secure */
   CLA1_MSGRAMHIGH     : origin = 0x001500, length = 0x000080     /* CPU to CLA Message RAM, DCSM secure */
   RAMLS0              : origin = 0x008000, length = 0x000800     /* L0 RAM, DCSM secure, CLA Data RAM */
   RAMLS1              : origin = 0x008800, length = 0x000800     /* RESERVED FOR TOBIAS L1 RAM, DCSM secure, CLA Data RAM */
   RAMLS2              : origin = 0x009000, length = 0x000800     /* L2 RAM, DCSM secure, CLA Data RAM */
   RAMLS3              : origin = 0x009800, length = 0x000800     /* L3 RAM, DCSM secure, CLA Data RAM */
/*   RAMLS5D0D1          : origin = 0x00A800, length = 0x001800     /* L5 RAM, DCSM secure, CLA Program RAM */
   RAMD0D1             : origin = 0x00B000, length = 0x001000     /* D0D1 RAM, DCSM secure, CLA Data RAM */
/*   RAMD0               : origin = 0x00B000, length = 0x000800     /* D0 RAM, DCSM secure, ECC */
/*   RAMD1               : origin = 0x00B800, length = 0x000800     /* D1 RAM, DCSM secure, ECC */
   RAMGS0123           : origin = 0x000C000, length = 0x004000     /* GS8-15 RAM, Parity, DMA */
   RAMGS456789ABCDEF   : origin = 0x010000, length = 0x00C000     /* GS8-15 RAM, Parity, DMA */
}

 
SECTIONS
{
/*** Compiler Required Sections ***/

  /* Program memory (PAGE 0) sections */
   .text               : > FLASH_BCDEFG,   PAGE = 0                       //Executable code and constants
   .cinit              : > FLASH_BCDEFG,   PAGE = 0                       //Tables for explicitly initialized global and static variables
   .const              : > FLASH_BCDEFG,   PAGE = 0                       //Global and static const variables that are explicitly initialized (EABI only)
   .econst             : > FLASH_BCDEFG,   PAGE = 0                       //Global and static const variables that are explicitly initialized (COFF only)
   .pinit              : > FLASH_BCDEFG,   PAGE = 0                       //Table of constructors to be called at startup. (COFF only)
   .reset              : > RESET,          PAGE = 0, TYPE = DSECT  /* Not using the .reset section */
   .switch             : > FLASH_BCDEFG,   PAGE = 0                       //Jump tables for large switch statements

  /* Data Memory (PAGE 1) sections */
   .bss                : > RAMM0,                 PAGE = 1                //Global and static variables (EABI only)
   .ebss               : >> RAMLS3 | RAMD0D1 ,    PAGE = 1                //Global and static variables (COFF only)
   .cio                : > RAMM0,                 PAGE = 1
   .stack              : > RAMLS1,                PAGE = 1                // do not assign stack to page0 cf bug 22/01/2021
   .sysmem             : > RAMM1,                 PAGE = 1                //Memory for malloc functions (heap) (EABI only)
   .esysmem            : > RAMM1,                 PAGE = 1                //Memory for malloc functions (heap) (COFF only)

/*** CLA Compiler Required Sections ***/
   .scratchpad         : > RAMLS0,                PAGE = 1                /* Scratchpad memory for the CLA C Compiler */
   .bss_cla			   : > RAMLS0,                PAGE = 1

/*** User Defined Sections ***/
   codestart           : > BEGIN_FLASH,           PAGE = 0                /* Used by file CodeStartBranch.asm */
   Cla1ToCpuMsgRAM     : > CLA1_MSGRAMLOW,        PAGE = 1                /* Link to CLA Message RAM */
   CpuToCla1MsgRAM     : > CLA1_MSGRAMHIGH,       PAGE = 1                /* Link to CLA Message RAM */
   CpuClaData		   : > RAMLS0,                PAGE = 1
   dataloadfile        : > RAMGS456789ABCDEF,     PAGE = 1
   dataloaderFlashdata : > FLASHMN,      PAGE = 0
   dataloaderFlash     : > FLASHMN,      PAGE = 0

   /* Section secureRamFuncs used by file Flash.c. */
   secureRamFuncs      : LOAD = FLASH_BCDEFG, PAGE = 0            /* Load to flash, run from DCSM secure RAM */
                         RUN = RAMLS5,        PAGE = 0
                         LOAD_START(_secureRamFuncs_loadstart),
                         LOAD_SIZE(_secureRamFuncs_loadsize),
                         RUN_START(_secureRamFuncs_runstart)

   Cla1Prog            : LOAD = FLASH_BCDEFG, PAGE = 0
                         RUN = RAMLS0,	      PAGE = 1
                         LOAD_START(_Cla1ProgLoadStart),
                         LOAD_SIZE(_Cla1ProgLoadSize),
                         RUN_START(_Cla1ProgRunStart)


   GROUP
        {
            RamFuncSection
            { -l F021_API_F2837xD_FPU32.lib}

        } LOAD = FLASHMN, PAGE = 0, ALIGN(4)
          RUN  = RAMLS2, PAGE = 1
          LOAD_START(_RamfuncsLoadStart),
          LOAD_SIZE(_RamfuncsLoadSize),
          LOAD_END(_RamfuncsLoadEnd),
          RUN_START(_RamfuncsRunStart),
          RUN_SIZE(_RamfuncsRunSize),
          RUN_END(_RamfuncsRunEnd)
}

/******************* end of file ************************/
